@@ -373,6 +373,7 @@ fn render_options_menu<B: Backend>(
 			.block(
 				Block::default()
 					.title("Options")
+					.title_alignment(Alignment::Center)
 					.style(if app.state.colored {
 						Style::default().fg(Color::LightBlue)
 					} else {
@@ -586,7 +587,7 @@ mod tests {
 			Buffer::with_lines(vec![
 			"┌────────────────────────────────────────────────────────────────────┐",
 			&test_key,
-			"│               ┌Options─────────────────────────────┐               │",
+			"│               ┌──────────────Options───────────────┐               │",
 			"│  [sc--] rsa409│> close menu                        │ail.com        │",
 			"│               │  show help                         │               │",
 			"│               │  refresh application               │               │",
